@@ -7,7 +7,7 @@ import graphql
 class GraphQLField:
     """Composition to add unwrapped_field to graphql.GraphQLField. GraphQLField uses
     slots, so we cannot just set the attr """
-    unwrapped_field: graphql.GraphQLObjectType = None
+    unwrapped_type: graphql.GraphQLObjectType = None
     _graphql_field: graphql.GraphQLField
 
     def __init__(self, g_field) -> None:
